"use server"

import prisma from "@/lib/prisma"
import { commissionTypeSchema } from "@/schemas/commissionType"
import * as z from "zod/v4"

export async function updateCommissionType(
  id: string,
  rawData: z.infer<typeof commissionTypeSchema>
) {
  const data = commissionTypeSchema.parse(rawData)

  const updated = await prisma.commissionType.update({
    where: { id },
    data: {
      name: data.name,
      description: data.description,
      options: {
        deleteMany: {},
        create: data.options?.map((opt, index) => ({
          option: { connect: { id: opt.optionId } },
          price: opt.price ?? null,
          pricePercent: opt.pricePercent ?? null,
          priceRange: opt.priceRange ?? null,
          sortIndex: index,
        })),
      },
      extras: {
        deleteMany: {},
        create: data.extras?.map((ext, index) => ({
          extra: { connect: { id: ext.extraId } },
          price: ext.price ?? null,
          pricePercent: ext.pricePercent ?? null,
          priceRange: ext.priceRange ?? null,
          sortIndex: index,
        })),
      },
    },
    include: {
      options: true,
      extras: true,
    },
  })

  return updated
}
