import {
  useSortable
} from "@dnd-kit/sortable"
import { CSS } from "@dnd-kit/utilities"

export default function SortableItem({
  id,
  children,
}: {
  id: string
  children: React.ReactNode
}) {
  const {
    attributes,
    listeners, // 👈 the key to handle-only dragging
    setNodeRef,
    transform,
    transition,
    isDragging,
  } = useSortable({ id })

  const style = {
    transform: CSS.Transform.toString(transform),
    transition,
    zIndex: isDragging ? 50 : "auto",
    opacity: isDragging ? 0.7 : 1,
  }

  return (
    <div
      ref={setNodeRef}
      style={style}
      className={`transition-all duration-200 ease-in-out ${isDragging ? "ring-2 ring-primary rounded-md shadow-lg" : ""
        }`}
    >
      <div className="flex items-start gap-2 min-h-[4rem]">
        <div
          {...listeners}
          {...attributes}
          className="cursor-grab px-1 pt-2 text-muted-foreground select-none"
          title="Drag to reorder"
        >
          ☰
        </div>
        <div className="w-full">{children}</div>
      </div>
    </div>
  )
}
