"use client"

import { createCommissionType } from "@/actions/items/commissions/types/newType";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { CommissionExtra, CommissionOption } from "@/generated/prisma";
import { commissionTypeSchema } from "@/schemas/commissionType";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";
import { CommissionExtraField } from "./form/CommissionExtraField";
import { CommissionOptionField } from "./form/CommissionOptionField";

type Props = {
  options: CommissionOption[],
  extras: CommissionExtra[],
}

export default function NewTypeForm({ options, extras }: Props) {
  const router = useRouter();
  const form = useForm<z.infer<typeof commissionTypeSchema>>({
    resolver: zodResolver(commissionTypeSchema),
    defaultValues: {
      name: "",
      description: "",
      options: [],
      extras: [],
    },
  })

  async function onSubmit(values: z.infer<typeof commissionTypeSchema>) {
    try {
      const created = await createCommissionType(values)
      console.log("CommissionType created:", created)
      toast("Commission type created.")
      router.push("/items/commissions/types")
    } catch (err) {
      console.error(err)
      toast("Failed to create commission type.")
    }
  }

  return (
    <div className="flex flex-col gap-8">
      <Form {...form}>
        <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
          <FormField
            control={form.control}
            name="name"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Name</FormLabel>
                <FormControl>
                  <Input {...field} />
                </FormControl>
                <FormDescription>The name of the commission type.</FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="description"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Description</FormLabel>
                <FormControl>
                  <Input {...field} />
                </FormControl>
                <FormDescription>Optional description.</FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />

          <CommissionOptionField options={options} />
          <CommissionExtraField extras={extras} />

          <div className="flex flex-col gap-4">
            <Button type="submit">Submit</Button>
            <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
          </div>
        </form>
      </Form>
    </div>
  );
}